@@ -23,6 +23,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include <charmap.h>
 #include <yaz/test.h>
 #include <stdlib.h>
+#include <string.h>
 
 /* use env srcdir as base directory - or current directory if unset */
 const char *get_srcdir(void)
@@ -34,13 +35,43 @@ const char *get_srcdir(void)
 
 }
 
-void tst1(void)
+void tst_string(chrmaptab tab, const char *input, int value) {
+    const char **output;
+    const char *from = input;
+    int len = strlen(from);
+    output = chr_map_input_x(tab, &from, &len, 0);
+    YAZ_CHECK_EQ(0, len);
+    YAZ_CHECK(output);
+    if (output)
+    {
+        YAZ_CHECK(*output);
+        YAZ_CHECK_EQ(value, output[0][0]);
+    }
+}
+
+void tst_latin1(void)
 {
     /* open existing map chrmaptab.chr */
     chrmaptab tab = chrmaptab_create(get_srcdir() /* tabpath */,
 				     "tstcharmap.chr" /* file */,
 				     0 /* tabroot */ );
     YAZ_CHECK(tab);
+    tst_string(tab, "b", 16);
+    tst_string(tab, "æ", 42);
+    tst_string(tab, "Æ", 42);
+    chrmaptab_destroy(tab);
+}
+
+void tst_utf8(void)
+{
+    /* open existing map chrmaptab.chr */
+    chrmaptab tab = chrmaptab_create(get_srcdir() /* tabpath */,
+				     "tstcharmap_utf8.chr" /* file */,
+				     0 /* tabroot */ );
+    YAZ_CHECK(tab);
+    tst_string(tab, "b", 16);
+    tst_string(tab, "æ", 42);
+    tst_string(tab, "Æ", 42);
     chrmaptab_destroy(tab);
 }
 
@@ -69,7 +100,8 @@ int main(int argc, char **argv)
     YAZ_CHECK_INIT(argc, argv);
     YAZ_CHECK_LOG();
 
-    tst1();
+    tst_latin1();
+    tst_utf8();
     tst2();
     tst3();
 
